#!/bin/bash
#
# source: http://download.icu-project.org/files/icu4c/4.4.1/icu4c-4_4_1-src.tgz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="icu"
softversion="4.4.1"
packageversion="66.1"

arch="i486"
cpu="i686"

buildir=$(pwd)
srcpkg="$buildir/icu4c-4_4_1-src.tgz"
src="$buildir/$soft"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

   |-----handy-ruler----------------------------------------------------------|
icu: icu - International Components for Unicode
icu:
icu: ICU is a mature, widely used set of C/C++ and Java libraries for Unicode
icu: support, software internationalization and globalization (i18n/g11n). It
icu: grew out of the JDK 1.1 internationalization APIs, which the ICU team
icu: contributed, and the project continues to be developed for the most
icu: advanced Unicode/i18n support. ICU is widely portable and gives
icu: applications the same results on all  platforms and between C/C++ and 
icu: Java software.
icu:
icu: 
EODESC

cd $src/source

#------------------Set correct permissions

chown -R root.root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

gzip -9 $dest/usr/man/*/*

#-------------------Prepare the documentation:

cd $src
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a *.txt *.html $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/doc/$soft-$softversion/html
cd $dest/usr/doc/$soft-$softversion/html
unzip $buildir/icu4c-4_0-docs.zip
mkdir -p $dest/usr/doc/$soft-$softversion/userguide
cd $dest/usr/doc/$soft-$softversion/userguide
unzip $buildir/icu-4_0-userguide.zip

#-------------------copy the build-script in /usr/src

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
md5sum $package.txz > $package.md5
